# CHANGELOG

## v1.1.0 (2024-10-10)

### Feature

* feat: added utils module with some commonly used functions ([`0f114b1`](https://github.com/NaturalAntibody/riot_na/commit/0f114b176b926aab7133101b0d0340abc5f42866))

### Unknown

* Merge pull request #7 from NaturalAntibody/utils_module

feat: added utils module with some commonly used functions ([`0a3e61c`](https://github.com/NaturalAntibody/riot_na/commit/0a3e61c76d9be0f12b6e18bc55419bbf472ecaab))

## v1.0.5 (2024-09-19)

### Chore

* chore: bump scikit-bio version ([`058bf43`](https://github.com/NaturalAntibody/riot_na/commit/058bf436d5cb8cb2586ad1fc56a1312ca746946c))

* chore: regenerate poetry.lock ([`f280de3`](https://github.com/NaturalAntibody/riot_na/commit/f280de3dced15221c3eec21a019aa167e609da0f))

### Fix

* fix: unpin dependencies&#39; fix version ([`8053596`](https://github.com/NaturalAntibody/riot_na/commit/8053596cacfaca9c7062b1d2180960b083ddd04c))

### Refactor

* refactor: fix linter errors ([`f82c6bd`](https://github.com/NaturalAntibody/riot_na/commit/f82c6bd6320c34f2c29e75071638e23b90408c16))

### Unknown

* bump: 1.0.5 [skip ci]

Automatically generated by python-semantic-release ([`fdf43f3`](https://github.com/NaturalAntibody/riot_na/commit/fdf43f3e91644461c0748f04db731b3d7208996e))

* Merge pull request #5 from NaturalAntibody/Unpin-dependencies&#39;-fix-versions

Unpin dependencies&#39; fix versions ([`8ac9264`](https://github.com/NaturalAntibody/riot_na/commit/8ac9264e5eab9bfe8fcc72efe90733ebd1aa1efa))

## v1.0.4 (2024-06-26)

### Fix

* fix: Update README.md ([`8422270`](https://github.com/NaturalAntibody/riot_na/commit/84222708f7fb1c06cd74d15fb1b057d617242e2d))

### Unknown

* bump: 1.0.4 [skip ci]

Automatically generated by python-semantic-release ([`4b784a0`](https://github.com/NaturalAntibody/riot_na/commit/4b784a089e9a806fb01ced459af2a18278a028c9))

* Merge pull request #3 from NaturalAntibody/update_readme

fix: Update README.md ([`d88edcf`](https://github.com/NaturalAntibody/riot_na/commit/d88edcf143aad49d0b5a0087788d936ae1128524))

## v1.0.3 (2024-06-26)

### Fix

* fix: update README - add links, quickstart instructions and development section ([`46d074e`](https://github.com/NaturalAntibody/riot_na/commit/46d074eac245ef67f3e6ce4c607b90fe94a6c907))

### Refactor

* refactor: fix workflow ([`a8cb445`](https://github.com/NaturalAntibody/riot_na/commit/a8cb4459f9151e98b7d203e0c94ba607d0b58feb))

* refactor: refactored citing section ([`52d9c7c`](https://github.com/NaturalAntibody/riot_na/commit/52d9c7c1d6526c9458089ae27184df78867f0591))

* refactor: added citing section ([`40551ee`](https://github.com/NaturalAntibody/riot_na/commit/40551eef5844eaf40587dadabaff0751441ca1e8))

* refactor: stylistic change ([`a2f9b40`](https://github.com/NaturalAntibody/riot_na/commit/a2f9b403e3d788f368d85ac85e4f742719281798))

### Unknown

* bump: 1.0.3 [skip ci]

Automatically generated by python-semantic-release ([`112d33c`](https://github.com/NaturalAntibody/riot_na/commit/112d33c72217d648dc353098f8cf71949d27b2a5))

* Merge pull request #2 from NaturalAntibody/update_readme

refactor: fix workflow ([`8a91813`](https://github.com/NaturalAntibody/riot_na/commit/8a9181314813f244453b65cdae762b896ac7d625))

* Merge pull request #1 from NaturalAntibody/update_readme

fix: update README - add links, quickstart instructions and developme… ([`7ba4982`](https://github.com/NaturalAntibody/riot_na/commit/7ba4982f8088101c561407f20e950e56a2033b33))

## v1.0.2 (2024-06-26)

### Fix

* fix: added short description and homepage ([`69985eb`](https://github.com/NaturalAntibody/riot_na/commit/69985eb3c6f26e98367636826929a725899c443b))

### Unknown

* bump: 1.0.2 [skip ci]

Automatically generated by python-semantic-release ([`70b2c6b`](https://github.com/NaturalAntibody/riot_na/commit/70b2c6bb03bcda57944b0fbfdcd117d6dafd773e))

## v1.0.1 (2024-06-25)

### Fix

* fix: update README ([`a4d35f9`](https://github.com/NaturalAntibody/riot_na/commit/a4d35f9254c1f5edc911cd4489de326cfda5305b))

### Unknown

* bump: 1.0.1 [skip ci]

Automatically generated by python-semantic-release ([`90aba93`](https://github.com/NaturalAntibody/riot_na/commit/90aba93e8f21c8bc84f15bbf3f42e92aba2a414a))

## v1.0.0 (2024-06-25)

### Breaking

* feat!: init commit ([`8228cf2`](https://github.com/NaturalAntibody/riot_na/commit/8228cf2144a8a348c35c437121954c4797569f2d))

### Unknown

* bump: 1.0.0 [skip ci]

Automatically generated by python-semantic-release ([`2db4fdc`](https://github.com/NaturalAntibody/riot_na/commit/2db4fdc3545e8e1a940f04deda11ad2a7f2926e7))
